package org.apache.bcel.generic;

import org.apache.bcel.classfile.ElementValue;
import org.apache.bcel.classfile.ConstantUtf8;
import java.io.IOException;
import java.io.DataOutputStream;
import org.apache.bcel.classfile.ClassElementValue;

public class ClassElementValueGen extends ElementValueGen
{
    private final int idx;
    
    public ClassElementValueGen(final ClassElementValue value, final ConstantPoolGen cpool, final boolean copyPoolEntries) {
        super(99, cpool);
        if (copyPoolEntries) {
            this.idx = cpool.addUtf8(value.getClassString());
        }
        else {
            this.idx = value.getIndex();
        }
    }
    
    protected ClassElementValueGen(final int typeIdx, final ConstantPoolGen cpool) {
        super(99, cpool);
        this.idx = typeIdx;
    }
    
    public ClassElementValueGen(final ObjectType t, final ConstantPoolGen cpool) {
        super(99, cpool);
        this.idx = cpool.addUtf8(t.getSignature());
    }
    
    @Override
    public void dump(final DataOutputStream dos) throws IOException {
        dos.writeByte(super.getElementValueType());
        dos.writeShort(this.idx);
    }
    
    public String getClassString() {
        final ConstantUtf8 cu8 = (ConstantUtf8)this.getConstantPool().getConstant(this.idx);
        return cu8.getBytes();
    }
    
    @Override
    public ElementValue getElementValue() {
        return new ClassElementValue(super.getElementValueType(), this.idx, this.getConstantPool().getConstantPool());
    }
    
    public int getIndex() {
        return this.idx;
    }
    
    @Override
    public String stringifyValue() {
        return this.getClassString();
    }
}
